# Indico Platform Management

This repository contains tools to create and manage Indico K8S clusters. It is used by the Indico Engineering Team and is also used for client installations.

- [Introduction and Setup](https://github.com/IndicoDataSolutions/indico-deployment/wiki/Introduction-and-Setup)
- [Wiki](https://github.com/IndicoDataSolutions/indico-deployment/wiki)
- [Contributing](#contributing)


## Contributing
When making any changes to the CLI or tools, please appropriately document them in the wiki and include the updated pages as part of your PR.
